 - Pydnatic2
   - request in pydantic context
 - CSRF changes
 - Auth async support
 - Schema.Meta
 - pagination: request in paginate_queryset
 - decorators
 - openapi docs plugable
 - add_router supports strings

TODO:
 - extra=forbid
 - Shorter annotations
 - Router@'auth' has already been attached to API NinjaAPI:1.0.0
 - https://github.com/vitalik/django-ninja/issues/428
 - async pagination

Backwards incompatible stuff
 - resolve_xxx(self, ...)
 - pydantic v1